%define aprver 1
%define major 0
%define libname %mklibname apr %{aprver} %{major}
%define develname %mklibname -d apr

Summary:	Apache Portable Runtime library
Name:		apr
Epoch:		1
Version:	1.7.0
Release:	%mkrel 3
License:	Apache License
Group:		System/Libraries
URL:		http://apr.apache.org/
Source0:	http://www.apache.org/dist/apr/apr-%{version}.tar.bz2
Source1:	http://www.apache.org/dist/apr/apr-%{version}.tar.bz2.asc
Patch0:		apr-1.5.0-deplibs.patch
Patch1:		apr-1.4.6-config.diff
Patch2:		apr-1.0.0-mutextype_reorder.diff
Patch3:		apr-1.2.2-deepbind.diff
Patch4:		apr-1.2.2-locktimeout.patch
BuildRequires:	autoconf
BuildRequires:	automake
BuildRequires:	libtool
BuildRequires:	doxygen
BuildRequires:	python3
BuildRequires:	pkgconfig(uuid)

%description
The mission of the Apache Portable Runtime (APR) is to provide a free library
of C data structures and routines, forming a system portability layer to as
many operating systems as possible, including Unices, MS Win32, BeOS and OS/2.

%package -n	%{libname}
Summary:	Apache Portable Runtime library
Group: 		System/Libraries
Provides:	lib%{name} = %{epoch}:%{version}-%{release}
Obsoletes:	lib%{name}
Obsoletes:	%{_lib}apr1 < %{epoch}:%{version}-%{release}

%description -n	%{libname}
The mission of the Apache Portable Runtime (APR) is to provide a free library
of C data structures and routines, forming a system portability layer to as
many operating systems as possible, including Unices, MS Win32, BeOS and OS/2.

%package -n	%{develname}
Summary:	APR library development kit
Group:		Development/C
Requires:	%{libname} = %{epoch}:%{version}
Provides:	%{mklibname apr -d 1} = %{epoch}:%{version}-%{release}
Obsoletes:	%{mklibname apr -d 1}
Provides:	%{name}-devel = %{epoch}:%{version}-%{release}
Obsoletes:	%{name}-devel
Requires:	libtool

%description -n	%{develname}
This package provides the support files which can be used to build applications
using the APR library. The mission of the Apache Portable Runtime (APR) is to
provide a free library of C data structures and routines.

%prep

%setup -q
#patch0 -p1 -b .deplibs
#patch1 -p1 -b .config
#patch2 -p0 -b .mutextype_reorder
# We're not applying this patch because RTLD_DEEPBIND breaks the mod_dav_svn.so
# of subversion-1.7.1 due to pointer mismatches in loaded shared libraries.
# See: http://subversion.tigris.org/issues/show_bug.cgi?id=4068
# ( -- Shlomi Fish )
# %patch3 -p0 -b .deepbind
#patch4 -p0 -b .locktimeout

cat >> config.layout << EOF
<Layout NUX>
    prefix:        %{_prefix}
    exec_prefix:   %{_prefix}
    bindir:        %{_bindir}
    sbindir:       %{_sbindir}
    libdir:        %{_libdir}
    libexecdir:    %{_libexecdir}
    mandir:        %{_mandir}
    infodir:       %{_infodir}
    includedir:    %{_includedir}/apr-%{aprver}
    sysconfdir:    %{_sysconfdir}
    datadir:       %{_datadir}
    installbuilddir: %{_libdir}/apr-%{aprver}/build
    localstatedir: /var
    runtimedir:    /var/run
    libsuffix:     -\${APR_MAJOR_VERSION}
</Layout>
EOF

perl -i -lpe 's/^(\s*)testsock\.lo(\s)/$1$2/' test/Makefile.in
perl -i -lnE 'say unless /^\s*\{testsock\},\s*$/' test/abts_tests.h

# python shebangs
pathfix.py -pni "%{__python3} %{py3_shbang_opts}" build/gen-build.py

%build
%serverbuild

# We need to re-run ./buildconf because of any applied patch(es)
#rm -f configure; sh ./buildconf
#./buildconf

# Forcibly prevent detection of shm_open (which then picks up but
# does not use -lrt).
# disable robust process-shared mutex support on arm because it makes the
# test hang
cat >> config.cache << EOF
ac_cv_search_shm_open=no
%ifarch %arm
apr_cv_mutex_robust_shared=no
%endif
EOF

%configure \
    --disable-static \
    --cache-file=config.cache \
    --includedir=%{_includedir}/apr-%{aprver} \
    --with-installbuilddir=%{_libdir}/apr-%{aprver}/build \
    --enable-layout=NUX \
%ifarch %ix86
%ifnarch i386 i486
    --enable-nonportable-atomics=yes \
%endif
%endif
    --enable-lfs \
    --enable-threads \
    --with-sendfile  \
    --with-devrandom=/dev/urandom

%make_build
make dox

%check
make check

%install
%make_install

# These are referenced by apr_rules.mk
for f in make_exports.awk make_var_export.awk; do
    install -m0644 build/${f} %{buildroot}%{_libdir}/apr-%{aprver}/build/${f}
done

install -m0755 build/mkdir.sh %{buildroot}%{_libdir}/apr-%{aprver}/build/mkdir.sh

# these are needed if apr-util is ./buildconf'ed
for f in apr_common.m4 apr_hints.m4 apr_network.m4 apr_threads.m4 find_apr.m4; do
    install -m0644 build/${f} %{buildroot}%{_libdir}/apr-%{aprver}/build/${f}
done
install -m0755 build/gen-build.py %{buildroot}%{_libdir}/apr-%{aprver}/build/

# enforce system libtool
ln -snf %{_bindir}/libtool %{buildroot}%{_libdir}/apr-%{aprver}/build/libtool

# Sanitize apr_rules.mk
sed -e "/^apr_build/d" \
    -e 's|$(apr_builders)|%{_libdir}/apr-%{aprver}/build|g' \
    -e 's|$(apr_builddir)|%{_libdir}/apr-%{aprver}/build|g' \
    -e 's|$(top_builddir)|%{_libdir}/apr-%{aprver}/build|g' \
    < build/apr_rules.mk > %{buildroot}%{_libdir}/apr-%{aprver}/build/apr_rules.mk

# Move docs to more convenient location
rm -rf html
cp -r docs/dox/html html


# here too
perl -pi -e "s|-luuid -lcrypt||g" \
    %{buildroot}%{_bindir}/apr-%{aprver}-config \
    %{buildroot}%{_libdir}/pkgconfig/*.pc

# Unpackaged files:
rm -f %{buildroot}%{_libdir}/apr.exp
find %{buildroot} -name '*.la' -delete

# extra headers
install -d %{buildroot}%{_includedir}/apr-%{aprver}/arch/unix
install -m0644 include/arch/apr_private_common.h %{buildroot}%{_includedir}/apr-%{aprver}/arch/
install -m0644 include/arch/unix/*.h %{buildroot}%{_includedir}/apr-%{aprver}/arch/unix/

%files -n %{libname}
%doc CHANGES README*
%{_libdir}/libapr-%{aprver}.so.%{major}
%{_libdir}/libapr-%{aprver}.so.%{major}.*

%files -n %{develname}
%doc docs/APRDesign.html docs/canonical_filenames.html
%doc docs/incomplete_types docs/non_apr_programs
%doc html
%{_bindir}/apr-%{aprver}-config
%{_libdir}/libapr-%{aprver}.so
%dir %{_libdir}/apr-%{aprver}
%dir %{_libdir}/apr-%{aprver}/build
%{_libdir}/apr-%{aprver}/build/*
%{_libdir}/pkgconfig/*.pc
%dir %{_includedir}/apr-%{aprver}
%dir %{_includedir}/apr-%{aprver}/arch
%dir %{_includedir}/apr-%{aprver}/arch/unix
%{_includedir}/apr-%{aprver}/*.h
%{_includedir}/apr-%{aprver}/arch/*.h
%{_includedir}/apr-%{aprver}/arch/unix/*.h


%changelog
* Fri Aug 21 2020 pterjan <pterjan> 1:1.7.0-3.mga8
+ Revision: 1617752
- Do not run buildconf which breaks configure

* Sat Feb 15 2020 daviddavid <daviddavid> 1:1.7.0-2.mga8
+ Revision: 1525727
- fix python shebangs
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x
- replace deprecated %%makeinstall_std

* Mon Apr 08 2019 shlomif <shlomif> 1:1.7.0-1.mga7
+ Revision: 1387168
- New version 1.7.0

* Thu Nov 22 2018 shlomif <shlomif> 1:1.6.5-1.mga7
+ Revision: 1333205
- New version 1.6.5

* Sun Sep 23 2018 wally <wally> 1:1.6.3-4.mga7
+ Revision: 1302247
- add patch from upstream to fix hanging test with gcc 8.1
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Tue Oct 24 2017 shlomif <shlomif> 1:1.6.3-1.mga7
+ Revision: 1173241
- New version 1.6.3

* Sat Aug 26 2017 guillomovitch <guillomovitch> 1:1.6.2-1.mga7
+ Revision: 1148046
- new version 1.6.2

* Wed Feb 10 2016 umeabot <umeabot> 1:1.5.2-2.mga6
+ Revision: 953059
- Mageia 6 Mass Rebuild

* Sat Jun 20 2015 shlomif <shlomif> 1:1.5.2-1.mga6
+ Revision: 836678
- New version 1.5.2

* Wed Oct 15 2014 umeabot <umeabot> 1:1.5.1-3.mga5
+ Revision: 751079
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1:1.5.1-2.mga5
+ Revision: 677871
- Mageia 5 Mass Rebuild

* Sat Apr 26 2014 luigiwalser <luigiwalser> 1:1.5.1-1.mga5
+ Revision: 618282
- 1.5.1

* Fri Nov 29 2013 guillomovitch <guillomovitch> 1:1.5.0-1.mga4
+ Revision: 554065
- new version
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Sun Jun 30 2013 luigiwalser <luigiwalser> 1:1.4.8-1.mga4
+ Revision: 448433
- 1.4.8
- remove patches 5 and 6 (fixed upstream)

* Mon Apr 01 2013 colin <colin> 1:1.4.6-5.mga3
+ Revision: 407027
- Fix return value of apr_sockaddr_info_get() when no sockaddr is set mga#9579

* Fri Jan 11 2013 umeabot <umeabot> 1:1.4.6-4.mga3
+ Revision: 345960
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Dec 26 2012 pterjan <pterjan> 1:1.4.6-3.mga3
+ Revision: 335371
- Fix doc files list for new rpm
+ luigiwalser <luigiwalser>
- update config patch (from mdv)

* Tue Feb 14 2012 luigiwalser <luigiwalser> 1:1.4.6-1.mga2
+ Revision: 208697
- 1.4.6 (fixes CVE-2012-0840)

* Sun Dec 11 2011 fwang <fwang> 1:1.4.5-8.mga2
+ Revision: 180539
- force return -l rather than plain LA_FILE

* Sun Dec 11 2011 fwang <fwang> 1:1.4.5-7.mga2
+ Revision: 180535
- finally deal with libtool location

* Sat Dec 10 2011 fwang <fwang> 1:1.4.5-6.mga2
+ Revision: 180024
- force to use .so file

* Sat Dec 10 2011 fwang <fwang> 1:1.4.5-5.mga2
+ Revision: 179998
- correct libname

* Fri Dec 09 2011 fwang <fwang> 1:1.4.5-4.mga2
+ Revision: 179603
- add requires on libtool for the symlink

* Fri Dec 09 2011 fwang <fwang> 1:1.4.5-3.mga2
+ Revision: 179599
- drop .la files

* Mon Nov 28 2011 shlomif <shlomif> 1:1.4.5-2.mga2
+ Revision: 173809
- Commented out applying the RTDL_DEEPBIND patch which broke svn-1.7.1
+ fwang <fwang>
- correctly set epoch
- new version 1.4.5 ( drop merged patches )

* Fri May 20 2011 dmorgan <dmorgan> 1.4.2-8.mga1
+ Revision: 99923
- P7: security fixes for CVE-2011-0419, CVE-2011-1928 (upstream svn)

* Thu May 19 2011 dmorgan <dmorgan> 1.4.2-7.mga1
+ Revision: 99802
- Fix P7 name

* Sun May 15 2011 dmorgan <dmorgan> 1.4.2-6.mga1
+ Revision: 98877
- P7: security fix for CVE-2011-0419 (rhel6)
+ rtp <rtp>
- disable robust process-shared mutex support on arm

* Wed Jan 12 2011 ahmad <ahmad> 1.4.2-5.mga1
+ Revision: 7622
- drop old/unneeded scriptlets
- imported package apr

